@@ -32,10 +32,10 @@ apply_base_algorithm <- function(x, algorithm, ...) {
   { data <- na_ma(data,  ...) }
   
   else 
-  {stop("Wrong parameter for option algorithm choosen.")}
-  
-  
+  {
+    stop("Wrong parameter for option algorithm chosen.")
+  }
   
   return(data)
   
-}
\ No newline at end of file
+}
